@@ -1,9 +1,9 @@
 #
-# $Id: Split.pm,v 0.42 2004/01/05 12:15:36 sts Exp $
+# $Id: Split.pm,v 0.43 2004/01/06 11:12:18 sts Exp $
 
 package Dir::Split;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use 5.6.1;
 use strict;
@@ -134,13 +134,13 @@ sub new {
 #
 
 sub _tie_var {
-    my (%assign, %assigned); 
+    my (%assign, %assigned);
 
     %assign = (  mode    =>    'mode',
 
                  source  =>    'source',
                  target  =>    'target',
-    
+
                  options => {  verbose     =>      'verbose',
                                override    =>     'override',
                  },
@@ -158,13 +158,13 @@ sub _tie_var {
     # hash ref
     if (ref $_[0]) {
         my $opt = $_[0];
-        foreach my $key (keys %{$opt}) {
-            if (ref ${$opt}{$key} eq 'HASH') {
-                foreach (keys %{${$opt}{$key}}) {
-                    $assigned{$assign{$key}{$_}} = ${$opt}{$key}{$_};
+        foreach my $key (keys %$opt) {
+            if (ref $$opt{$key} eq 'HASH') {
+                foreach (keys %{$$opt{$key}}) {
+                    $assigned{$assign{$key}{$_}} = $$opt{$key}{$_};
                 }
             }
-            else { $assigned{$assign{$key}} = ${$opt}{$key} }
+            else { $assigned{$assign{$key}} = $$opt{$key} }
         }
     }
     # hash
